### CHANGE LOG
---

#### 0.0.1 (25/07/2023)
- First Release

#### 0.0.2 (25/07/2023)
- Add Font Packages

#### 0.0.10 (25/07/2023)
- Fix Some Problems

#### 0.1.0 (26/07/2023)
- Add Subplot Function

#### 0.1.3 (26/07/2023)
- Fix Some Minor Problems

#### 0.1.5 (27/07/2023)
- Add Basic Basemap Function, fix some problems

#### 0.1.6 (27/07/2023)
- Fix Some Problems, add common raise function

#### 0.1.7 (27/07/2023)
- Fix Some Minor Problems

#### 0.1.8 (31/07/2023)
- Fix Some Minor Problems, add new cmap '35'

#### 0.2.0 (21/08/2023)
- Fix Some Minor Problems, add redirectfontfolder function

#### 0.2.1 (21/08/2023)
- Revise the description of the package

#### 0.2.2 (21/08/2023)
- Revise the description of the package

#### 0.2.3 (21/08/2023)
- Add usage description of the package

#### 0.2.4 (21/08/2023)
- Fix Some Minor Problems

#### 0.2.5 (21/08/2023)
- Add beautifyterminal module

#### 0.2.6 (22/08/2023)
- Fix Some Problems

#### 0.2.7 (23/08/2023)
- Some Minor Details Change

#### 0.2.8 (24/08/2023)
- Fix some colorbar problems

#### 0.2.14 (24/08/2023)
- Fix Some Minor Problems

#### 0.2.15 (25/08/2023)
- Fix fontfiles install problem

#### 0.2.20 (02/09/2023)
- Fix Some Minor Problems

#### 0.3.0 (02/09/2023)
- Solve the font problem that you don't have to manually install the font now

#### 0.3.2 (02/09/2023)
- Fix Some Minor Problems

#### 0.3.3 (04/09/2023)
- Fix Some Minor Problems

#### 0.3.5 (05/09/2023)
- Standardize description of the output hint

#### 0.3.6 (09/09/2023)
- New feature: add 'beautifymeteogram' for meteological plot (alpha edition)

#### 0.3.7 (09/09/2023)
- Fix Some Minor Problems

#### 0.3.8 (10/09/2023)
- Fix the theme problems of the meteogram
- Add hodograph function in the skew-T plot